These functions are the summary and print methods for objects of type
glmmNPML and glmmGQ.
# S3 method for glmmNPML
summary(object, digits = max(3, getOption("digits") - 3), ...)
# S3 method for glmmGQ
summary(object, digits = max(3, getOption("digits") - 3), ...)
# S3 method for glmmNPML
print(x, digits=max(3,getOption('digits')-3), ...)
# S3 method for glmmGQ
print(x, digits=max(3,getOption('digits')-3), ...)a fitted object of class glmmNPML or glmmGQ.
a fitted object of class glmmNPML or glmmGQ.
number of digits; applied on various displayed quantities.
further arguments, which will mostly be ignored.
Prints regression output or summary on screen.
Objects returned by summary.glmmNPML or summary.glmmGQ are
essentially identical to objects of class glmmNPML or glmmGQ.
However, their $coef component contains the parameter standard errors
and t values (taken from the GLM fitted in the last EM iteration), and they
have two additional components $dispersion and $lastglmsumm
providing the estimated dispersion parameter and a summary of the glm
fitted in the last EM iteration.
The summary...- and print... -functions invoke the generic
UseMethod(...) function and detect the right model class
automatically. In other words, it is enough to write
summary(...) or print(...).
Aitkin, M., Francis, B. and Hinde, J. (2009). Statistical Modelling in R. Oxford Statistical Science Series, Oxford, UK.